// Copyright  1995-1999 The Santa Fe Institute.
// No warranty implied, see LICENSE for terms.

#import "ObserverSwarm.h"
#import <simtools.h>

#include <misc.h>

int
main (int argc, const char **argv)
{
  id observerSwarm;

  // Swarm initialization
  initSwarm (argc, argv);

  observerSwarm = [ObserverSwarm create: [Zone create: globalZone]];
  [observerSwarm buildObjects];
  [observerSwarm buildActions];
  [observerSwarm activateIn: nil];
  [observerSwarm go];   

  exit (0);
}
